@@ -9,6 +9,7 @@
     :license: MIT, see LICENSE for more details.
 """
 
+
 class Datastore(object):
     def __init__(self, db):
         self.db = db
@@ -81,6 +82,10 @@ class UserDatastore(object):
         kwargs['roles'] = roles
         return kwargs
 
+    def get_user(self, id_or_email):
+        """Returns a user matching the specified ID or email address"""
+        raise NotImplementedError
+
     def find_user(self, *args, **kwargs):
         """Returns a user matching the provided parameters."""
         raise NotImplementedError
@@ -174,6 +179,11 @@ class SQLAlchemyUserDatastore(SQLAlchemyDatastore, UserDatastore):
         SQLAlchemyDatastore.__init__(self, db)
         UserDatastore.__init__(self, user_model, role_model)
 
+    def get_user(self, id_or_email):
+        return (self.user_model.query.get(id_or_email) or
+                self.user_model.query.filter(
+                    self.user_model.email.ilike(id_or_email)).first())
+
     def find_user(self, **kwargs):
         return self.user_model.query.filter_by(**kwargs).first()
 
@@ -189,15 +199,26 @@ class MongoEngineUserDatastore(MongoEngineDatastore, UserDatastore):
         MongoEngineDatastore.__init__(self, db)
         UserDatastore.__init__(self, user_model, role_model)
 
+    def get_user(self, id_or_email):
+        from mongoengine import ValidationError
+        try:
+            return self.user_model.objects(id=id_or_email).first()
+        except ValidationError:
+            return self.user_model.objects(email__iexact=id_or_email).first()
+
     def find_user(self, **kwargs):
         try:
             from mongoengine.queryset import Q, QCombination
         except ImportError:
             from mongoengine.queryset.visitor import Q, QCombination
+        from mongoengine.errors import ValidationError
 
         queries = map(lambda i: Q(**{i[0]: i[1]}), kwargs.items())
         query = QCombination(QCombination.AND, queries)
-        return self.user_model.objects(query).first()
+        try:
+            return self.user_model.objects(query).first()
+        except ValidationError:
+            return None
 
     def find_role(self, role):
         return self.role_model.objects(name=role).first()
@@ -216,6 +237,17 @@ class PeeweeUserDatastore(PeeweeDatastore, UserDatastore):
         UserDatastore.__init__(self, user_model, role_model)
         self.UserRole = role_link
 
+    def get_user(self, id_or_email):
+        try:
+            return self.user_model.get(self.user_model.id == id_or_email)
+        except ValueError:
+            pass
+        try:
+            return self.user_model.get(self.user_model.email ** id_or_email)
+        except self.user_model.DoesNotExist:
+            pass
+        return None
+
     def find_user(self, **kwargs):
         try:
             return self.user_model.filter(**kwargs).get()
