@@ -33,6 +33,10 @@ class DefaultSecurityTests(SecurityTest):
         r = self.authenticate()
         self.assertIn('Hello matt@lp.com', r.data)
 
+    def test_authenticate_case_insensitive_email(self):
+        r = self.authenticate(email='MATT@lp.com')
+        self.assertIn('Hello matt@lp.com', r.data)
+
     def test_unprovided_username(self):
         r = self.authenticate("")
         self.assertIn(self.get_message('EMAIL_NOT_PROVIDED'), r.data)
@@ -59,6 +63,7 @@ class DefaultSecurityTests(SecurityTest):
         self.assertIsHomePage(r.data)
 
     def test_unauthorized_access(self):
+        self.logout()
         r = self._get('/profile', follow_redirects=True)
         self.assertIn('<li class="info">Please log in to access this page.</li>', r.data)
 
